# Shortcuts Commands

Command | Action
--- | ---
`Control+N` | New file
`Control+O` | Open existing file
`Control+S` | Save current file
`Control+Shift+S` | Save current file as new file
`Control+W` | Close current file
`Control-P` | Print current file
`Control-Q` | Close the IDE
`Control-Z` | Undo
`Control-Y` | Redo
`Control-X` | Cut current selection
`Control-C` | Copy current selection
`Control-V` | Paste current selection
`Control+F` | Find some world
`Control+R` | Find and replace some world
`Control+/` | Comment selected text.
`Control+.` | Toggle comments in selected text
`Control+>` |
`Control+<` |
`Control+Shift+B` |
`Control+Shift+P` |
`F5` |
`F6` |
`F7` |
`F2` |
`F3` |
`Shift+F2` |
`Control+Shift+L` |
`Control+Shift+I` |